@@ -107,10 +107,15 @@ class MenuBar(QMenuBar):
         self._menu_tools = QMenu(_(u'&Tools'))
         self._menu_tools.addAction(self._action_preferences)
         self._menu_tools.addAction(self._action_plugins)
+        self._menu_tools.addSeparator()
         self._action_jupyter_notebook = self._add_extension_action(
             'JupyterNotebook',
             menu=self._menu_tools
         )
+        self._action_git_gui = self._add_extension_action(
+            'GitGUI',
+            menu=self._menu_tools
+        )
         self.addMenu(self._menu_tools)
         # View menu
         self._action_close_tab = self._action(
@@ -369,6 +374,9 @@ class MenuBar(QMenuBar):
         action.setIcon(self._ide.theme.qicon(icon))
         if shortcut:
             action.setShortcut(shortcut)
+            action.setToolTip(
+                '{} ({})'.format(title.replace('&', ''), shortcut)
+            )
         action.triggered.connect(target)
         if checkable:
             action.setCheckable(True)
